@@ -5,67 +5,46 @@
     <name>AdvancedSettings</name>
     <message>
         <location filename="../advancedsettings.ui" line="67"/>
-        <source>Sizes</source>
-        <translation>Tamanhos</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="75"/>
-        <source>Width:</source>
-        <translation>Largura:</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="82"/>
-        <location filename="../advancedsettings.ui" line="106"/>
-        <source> px</source>
-        <translation> px</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="99"/>
-        <source>Spacing:</source>
-        <translation>Espaçamento:</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="118"/>
         <source>Duration</source>
         <translation>Duração</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="130"/>
+        <location filename="../advancedsettings.ui" line="79"/>
         <source>Some notifications set their own on-screen duration.</source>
         <translation>Algumas notificações definem as suas próprias durações na tela.</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="142"/>
+        <location filename="../advancedsettings.ui" line="91"/>
         <source>Default duration:</source>
         <translation>Duração padrão:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="149"/>
+        <location filename="../advancedsettings.ui" line="98"/>
         <source> sec</source>
         <translation> seg</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="177"/>
+        <location filename="../advancedsettings.ui" line="126"/>
         <source>Screen</source>
         <translation>Tela</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="183"/>
+        <location filename="../advancedsettings.ui" line="132"/>
         <source>When unchecked the notification will always show on primary screen</source>
         <translation>Quando desmarcada, a notificação sempre será exibida na tela principal</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="186"/>
+        <location filename="../advancedsettings.ui" line="135"/>
         <source>Show notifications on screen with the mouse</source>
         <translation>Exibir notificações na tela com o mouse</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="196"/>
+        <location filename="../advancedsettings.ui" line="145"/>
         <source>Do Not Disturb</source>
         <translation>Não Perturbe</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="202"/>
+        <location filename="../advancedsettings.ui" line="151"/>
         <source>Only save notifications</source>
         <translation>Salve apenas notificações</translation>
     </message>
@@ -100,82 +79,103 @@
     <name>BasicSettings</name>
     <message>
         <location filename="../basicsettings.ui" line="17"/>
+        <source>Sizes</source>
+        <translation>Tamanhos</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="25"/>
+        <source>Width:</source>
+        <translation>Largura:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="32"/>
+        <location filename="../basicsettings.ui" line="56"/>
+        <source> px</source>
+        <translation> px</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="49"/>
+        <source>Spacing:</source>
+        <translation>Espaçamento:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="68"/>
         <source>Position on screen</source>
         <translation>Posição na tela</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="176"/>
+        <location filename="../basicsettings.ui" line="227"/>
         <source>Preview</source>
         <translation>Ver</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="63"/>
+        <location filename="../basicsettings.cpp" line="65"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
 Keep trying to connect…</source>
         <translation>&lt;b&gt;Atenção:&lt;/b&gt; o daemon de notificações demora para responder.
 Continua tentando se conectar…</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="72"/>
+        <location filename="../basicsettings.cpp" line="74"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation>&lt;b&gt;Atenção:&lt;/b&gt; Nenhum daemon de notificações está sendo executado.
 Um fallback será utilizado.</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="75"/>
+        <location filename="../basicsettings.cpp" line="77"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
         <translation>&lt;b&gt;Atenção:&lt;/b&gt; Um daemon de notificação externo (%1) está sendo executado.
 Estas configurações não surtirão efeito nele!</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="137"/>
+        <location filename="../basicsettings.cpp" line="142"/>
         <source>at top left</source>
         <translation>No canto superior esquerdo</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="139"/>
+        <location filename="../basicsettings.cpp" line="144"/>
         <source>at top center</source>
         <translation>No centro do topo</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="141"/>
+        <location filename="../basicsettings.cpp" line="146"/>
         <source>at top right</source>
         <translation>No canto superior direito</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="143"/>
+        <location filename="../basicsettings.cpp" line="148"/>
         <source>at center left</source>
         <translation>No centro à esquerda</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="145"/>
+        <location filename="../basicsettings.cpp" line="150"/>
         <source>at center right</source>
         <translation>No centro à direita</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="147"/>
+        <location filename="../basicsettings.cpp" line="152"/>
         <source>at bottom left</source>
         <translation>No canto inferior esquerdo</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="149"/>
+        <location filename="../basicsettings.cpp" line="154"/>
         <source>at bottom center</source>
         <translation>No centro inferior</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="151"/>
+        <location filename="../basicsettings.cpp" line="156"/>
         <source>at bottom right</source>
         <translation>No canto inferior direito</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="153"/>
+        <location filename="../basicsettings.cpp" line="158"/>
         <source>Notification demo </source>
         <translation>Notificação de teste </translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="154"/>
+        <location filename="../basicsettings.cpp" line="159"/>
         <source>This is a test notification.
  All notifications will now appear here on LXQt.</source>
         <translation>Esta é uma notificação para testes.
@@ -196,8 +196,8 @@ Estas configurações não surtirão efeito nele!</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="48"/>
-        <source>Position</source>
-        <translation>Posição</translation>
+        <source>Appearance</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
