@@ -5,67 +5,46 @@
     <name>AdvancedSettings</name>
     <message>
         <location filename="../advancedsettings.ui" line="67"/>
-        <source>Sizes</source>
-        <translation>Boyutlar</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="75"/>
-        <source>Width:</source>
-        <translation>Genişlik:</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="82"/>
-        <location filename="../advancedsettings.ui" line="106"/>
-        <source> px</source>
-        <translation> px</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="99"/>
-        <source>Spacing:</source>
-        <translation>Boşluk:</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="118"/>
         <source>Duration</source>
         <translation>Ekranda Kalma Süresi</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="130"/>
+        <location filename="../advancedsettings.ui" line="79"/>
         <source>Some notifications set their own on-screen duration.</source>
         <translation>Bazı birdirimler kendi ekranda kalma süresini ayarlar.</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="142"/>
+        <location filename="../advancedsettings.ui" line="91"/>
         <source>Default duration:</source>
         <translation>Öntanımlı süre:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="149"/>
+        <location filename="../advancedsettings.ui" line="98"/>
         <source> sec</source>
         <translation> sn</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="177"/>
+        <location filename="../advancedsettings.ui" line="126"/>
         <source>Screen</source>
         <translation>Ekran</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="183"/>
+        <location filename="../advancedsettings.ui" line="132"/>
         <source>When unchecked the notification will always show on primary screen</source>
         <translation>İşaretli olmadığında, bildirim her zaman birincil ekranda gösterilecektir</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="186"/>
+        <location filename="../advancedsettings.ui" line="135"/>
         <source>Show notifications on screen with the mouse</source>
         <translation>Fareyle ekranda bildirimleri göster</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="196"/>
+        <location filename="../advancedsettings.ui" line="145"/>
         <source>Do Not Disturb</source>
         <translation>Rahatsız Etme</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="202"/>
+        <location filename="../advancedsettings.ui" line="151"/>
         <source>Only save notifications</source>
         <translation>Yalnızca bildirimleri kaydet</translation>
     </message>
@@ -100,30 +79,51 @@
     <name>BasicSettings</name>
     <message>
         <location filename="../basicsettings.ui" line="17"/>
+        <source>Sizes</source>
+        <translation>Boyutlar</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="25"/>
+        <source>Width:</source>
+        <translation>Genişlik:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="32"/>
+        <location filename="../basicsettings.ui" line="56"/>
+        <source> px</source>
+        <translation> px</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="49"/>
+        <source>Spacing:</source>
+        <translation>Boşluk:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="68"/>
         <source>Position on screen</source>
         <translation>Ekrandaki konumu</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="176"/>
+        <location filename="../basicsettings.ui" line="227"/>
         <source>Preview</source>
         <translation>Önizleme</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="63"/>
+        <location filename="../basicsettings.cpp" line="65"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
 Keep trying to connect…</source>
         <translation>&lt;b&gt;Uyarı:&lt;/b&gt; bildirimler arka plan programının yanıt vermesi yavaş.
 Bağlanmaya devam et…</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="72"/>
+        <location filename="../basicsettings.cpp" line="74"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation>&lt;b&gt;Uyarı:&lt;/b&gt; Çalışan bir bildirim programı yok.
 Bir geri dönüş kullanılacaktır.</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="75"/>
+        <location filename="../basicsettings.cpp" line="77"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
         <translation>&lt;b&gt;Uyarı:&lt;/b&gt; Üçüncü parti bir bildirim programı (%1) çalışıyor.
@@ -131,52 +131,52 @@ These settings won&apos;t have any effect on it!</source>
 Bu ayarlar onu etkilemeyecek!</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="137"/>
+        <location filename="../basicsettings.cpp" line="142"/>
         <source>at top left</source>
         <translation>üst solda</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="139"/>
+        <location filename="../basicsettings.cpp" line="144"/>
         <source>at top center</source>
         <translation>üst ortada</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="141"/>
+        <location filename="../basicsettings.cpp" line="146"/>
         <source>at top right</source>
         <translation>üst sağda</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="143"/>
+        <location filename="../basicsettings.cpp" line="148"/>
         <source>at center left</source>
         <translation>orta solda</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="145"/>
+        <location filename="../basicsettings.cpp" line="150"/>
         <source>at center right</source>
         <translation>orta sağda</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="147"/>
+        <location filename="../basicsettings.cpp" line="152"/>
         <source>at bottom left</source>
         <translation>alt solda</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="149"/>
+        <location filename="../basicsettings.cpp" line="154"/>
         <source>at bottom center</source>
         <translation>alt ortada</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="151"/>
+        <location filename="../basicsettings.cpp" line="156"/>
         <source>at bottom right</source>
         <translation>alt sağda</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="153"/>
+        <location filename="../basicsettings.cpp" line="158"/>
         <source>Notification demo </source>
         <translation>Bildirim deneme </translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="154"/>
+        <location filename="../basicsettings.cpp" line="159"/>
         <source>This is a test notification.
  All notifications will now appear here on LXQt.</source>
         <translation>Bu bir test bildirimidir.
@@ -197,8 +197,8 @@ Bundan sonra LXQT masaüstünüzde tüm bildirimler burada gösterilecek.</trans
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="48"/>
-        <source>Position</source>
-        <translation>Konum</translation>
+        <source>Appearance</source>
+        <translation>Görünüm</translation>
     </message>
 </context>
 </TS>
