@@ -5,67 +5,46 @@
     <name>AdvancedSettings</name>
     <message>
         <location filename="../advancedsettings.ui" line="67"/>
-        <source>Sizes</source>
-        <translation>Розміри</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="75"/>
-        <source>Width:</source>
-        <translation>Ширина:</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="82"/>
-        <location filename="../advancedsettings.ui" line="106"/>
-        <source> px</source>
-        <translation> пікселів</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="99"/>
-        <source>Spacing:</source>
-        <translation>Пропуски:</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="118"/>
         <source>Duration</source>
         <translation>Тривалість</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="130"/>
+        <location filename="../advancedsettings.ui" line="79"/>
         <source>Some notifications set their own on-screen duration.</source>
         <translation>Деякі повідомлення мають власну тривалість показу на екрані.</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="142"/>
+        <location filename="../advancedsettings.ui" line="91"/>
         <source>Default duration:</source>
         <translation>Типова тривалість:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="149"/>
+        <location filename="../advancedsettings.ui" line="98"/>
         <source> sec</source>
         <translation> сек</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="177"/>
+        <location filename="../advancedsettings.ui" line="126"/>
         <source>Screen</source>
         <translation>Екран</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="183"/>
+        <location filename="../advancedsettings.ui" line="132"/>
         <source>When unchecked the notification will always show on primary screen</source>
         <translation>Якщо не встановлено прапорець, сповіщення завжди з&apos;являтимуться на основному екрані</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="186"/>
+        <location filename="../advancedsettings.ui" line="135"/>
         <source>Show notifications on screen with the mouse</source>
         <translation>Показувати сповіщення на екрані, на якому знаходиться вказівник</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="196"/>
+        <location filename="../advancedsettings.ui" line="145"/>
         <source>Do Not Disturb</source>
         <translation>Не турбувати</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="202"/>
+        <location filename="../advancedsettings.ui" line="151"/>
         <source>Only save notifications</source>
         <translation>Зберігати лише сповіщення</translation>
     </message>
@@ -100,82 +79,103 @@
     <name>BasicSettings</name>
     <message>
         <location filename="../basicsettings.ui" line="17"/>
+        <source>Sizes</source>
+        <translation>Розміри</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="25"/>
+        <source>Width:</source>
+        <translation>Ширина:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="32"/>
+        <location filename="../basicsettings.ui" line="56"/>
+        <source> px</source>
+        <translation> пікселів</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="49"/>
+        <source>Spacing:</source>
+        <translation>Пропуски:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="68"/>
         <source>Position on screen</source>
         <translation>Позиція на екрані</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="176"/>
+        <location filename="../basicsettings.ui" line="227"/>
         <source>Preview</source>
         <translation>Попередній перегляд</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="63"/>
+        <location filename="../basicsettings.cpp" line="65"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
 Keep trying to connect…</source>
         <translation>&lt;b&gt;Попередження:&lt;/b&gt; фонова служба сповіщень повільно відповідає.
 Продовжуємо спроби з&apos;єднання…</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="72"/>
+        <location filename="../basicsettings.cpp" line="74"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation>&lt;b&gt;Попередження:&lt;/b&gt; Жодного демону повідомлень не запущено.
 Буде використаний аварійний.</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="75"/>
+        <location filename="../basicsettings.cpp" line="77"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
         <translation>&lt;b&gt;Попередження&lt;/b&gt; Інший демон повідомлень (%1) запущено.
 Ці налаштування не мають впливу на нього!</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="137"/>
+        <location filename="../basicsettings.cpp" line="142"/>
         <source>at top left</source>
         <translation>вгорі ліворуч</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="139"/>
+        <location filename="../basicsettings.cpp" line="144"/>
         <source>at top center</source>
         <translation>вгорі в центрі</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="141"/>
+        <location filename="../basicsettings.cpp" line="146"/>
         <source>at top right</source>
         <translation>вгорі праворуч</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="143"/>
+        <location filename="../basicsettings.cpp" line="148"/>
         <source>at center left</source>
         <translation>в центрі ліворуч</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="145"/>
+        <location filename="../basicsettings.cpp" line="150"/>
         <source>at center right</source>
         <translation>в центрі праворуч</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="147"/>
+        <location filename="../basicsettings.cpp" line="152"/>
         <source>at bottom left</source>
         <translation>внизу ліворуч</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="149"/>
+        <location filename="../basicsettings.cpp" line="154"/>
         <source>at bottom center</source>
         <translation>внизу в центрі</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="151"/>
+        <location filename="../basicsettings.cpp" line="156"/>
         <source>at bottom right</source>
         <translation>внизу праворуч</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="153"/>
+        <location filename="../basicsettings.cpp" line="158"/>
         <source>Notification demo </source>
         <translation>Демонстрація сповіщень </translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="154"/>
+        <location filename="../basicsettings.cpp" line="159"/>
         <source>This is a test notification.
  All notifications will now appear here on LXQt.</source>
         <translation>Це тестове повідомлення.
@@ -196,8 +196,8 @@ These settings won&apos;t have any effect on it!</source>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="48"/>
-        <source>Position</source>
-        <translation>Розміщення</translation>
+        <source>Appearance</source>
+        <translation>Вигляд</translation>
     </message>
 </context>
 </TS>
