@@ -37,6 +37,7 @@
 NotificationLayout::NotificationLayout(QWidget *parent)
     : QWidget(parent),
       m_unattendedMaxNum(0),
+      m_doNotDisturb(false),
       m_cacheDateFormat(QL1S("yyyy-MM-dd-HH-mm-ss-zzz"))
 {
     setObjectName(QSL("NotificationLayout"));
@@ -77,6 +78,9 @@ void NotificationLayout::addNotification(uint id, const QString &application,
                                         bool noSave)
 {
 //    qDebug() << "NotificationLayout::addNotification" << id << application << summary << body << icon << timeout;
+    bool showNotification(!m_doNotDisturb
+                          // always show our test notifications
+                          || application == QL1S("lxqt-config-notificationd"));
     if (m_notifications.contains(id))
     {
         // TODO/FIXME: it can be deleted by timer in this block. Locking?
@@ -111,11 +115,13 @@ void NotificationLayout::addNotification(uint id, const QString &application,
                 this, &NotificationLayout::notificationActionCalled);
         m_notifications[id] = n;
         m_layout->addWidget(n);
-        n->show();
+        if (showNotification)
+            n->show();
     }
 
     checkHeight();
-    emit notificationAvailable();
+    if (showNotification)
+        emit notificationAvailable();
 
     // NOTE by pcman:
     // This dirty hack is used to workaround a weird and annoying repainting bug caused by Qt.
@@ -127,6 +133,24 @@ void NotificationLayout::addNotification(uint id, const QString &application,
         repaint();
 }
 
+// Can be called when the do-not-disturb mode ends.
+void NotificationLayout::showAllNotifications()
+{
+    if (m_notifications.isEmpty())
+        return;
+    QHashIterator<uint, Notification*> it(m_notifications);
+    while (it.hasNext())
+    {
+        it.next();
+        it.value()->show();
+    }
+    // as in NotificationLayout::addNotification()
+    checkHeight();
+    emit notificationAvailable();
+    if(m_notifications.count() == 1)
+        repaint();
+}
+
 void NotificationLayout::removeNotificationTimeout()
 {
     Notification *n = qobject_cast<Notification*>(sender());
