@@ -91,13 +91,21 @@ NotificationActionsButtonsWidget::NotificationActionsButtonsWidget(const QString
 
     for (const auto &action : qAsConst(m_actions))
     {
-        QPushButton *b = new QPushButton(action.second, this);
-        b->setObjectName(action.first);
+        auto &id    = action.first;
+        auto &label = action.second;
+
+        if (id == m_defaultAction && label.isEmpty())
+        {
+            continue;
+        }
+
+        QPushButton *b = new QPushButton(label, this);
+        b->setObjectName(id);
+        // Notifications do not have focus, and if they get focus under Wayland,
+        // we do not want to have a focus widget.
+        b->setFocusPolicy(Qt::NoFocus);
         l->addWidget(b);
         group->addButton(b);
-
-        if (action.first == m_defaultAction)
-            b->setFocus(Qt::OtherFocusReason);
     }
     connect(group, static_cast<void (QButtonGroup::*)(QAbstractButton*)>(&QButtonGroup::buttonClicked),
             this, &NotificationActionsButtonsWidget::actionButtonActivated);
@@ -122,17 +130,22 @@ NotificationActionsComboWidget::NotificationActionsComboWidget(const QStringList
 
     l->addWidget(new QLabel(tr("Actions:"), this));
     m_comboBox = new QComboBox(this);
+    m_comboBox->setFocusPolicy(Qt::NoFocus);
     int currentIndex = -1;
 
-    for (int i = 0; i < m_actions.count(); ++i)
+    for (const auto &action : qAsConst(m_actions))
     {
-        auto const & action = m_actions[i];
+        auto &id    = action.first;
+        auto &label = action.second;
 
-        m_comboBox->addItem(action.second, action.first);
-        if (action.first == m_defaultAction)
+        if (id == m_defaultAction)
         {
-            currentIndex = i;
+            if (label.isEmpty())
+                continue;
+            currentIndex = m_comboBox->count();
         }
+
+        m_comboBox->addItem(label, id);
     }
     l->addWidget(m_comboBox);
 
@@ -140,6 +153,7 @@ NotificationActionsComboWidget::NotificationActionsComboWidget(const QStringList
         m_comboBox->setCurrentIndex(currentIndex);
 
     QPushButton *b = new QPushButton(tr("OK"), this);
+    b->setFocusPolicy(Qt::NoFocus);
     l->addWidget(b);
     connect(b, &QPushButton::clicked,
             this, &NotificationActionsComboWidget::actionComboBoxActivated);
